==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/RoleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.RoleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a role on the cluster.
 * @property autoscaleConfiguration The autoscale configurations.
 * @property dataDisksGroups The data disks groups for the role.
 * @property encryptDataDisks Indicates whether encrypt the data disks.
 * @property hardwareProfile The hardware profile.
 * @property minInstanceCount The minimum instance count of the cluster.
 * @property name The name of the role.
 * @property osProfile The operating system profile.
 * @property scriptActions The list of script actions on the role.
 * @property targetInstanceCount The instance count of the cluster.
 * @property vMGroupName The name of the virtual machine group.
 * @property virtualNetworkProfile The virtual network profile.
 */
public data class RoleArgs(
    public val autoscaleConfiguration: Output<AutoscaleArgs>? = null,
    public val dataDisksGroups: Output<List<DataDisksGroupsArgs>>? = null,
    public val encryptDataDisks: Output<Boolean>? = null,
    public val hardwareProfile: Output<HardwareProfileArgs>? = null,
    public val minInstanceCount: Output<Int>? = null,
    public val name: Output<String>? = null,
    public val osProfile: Output<OsProfileArgs>? = null,
    public val scriptActions: Output<List<ScriptActionArgs>>? = null,
    public val targetInstanceCount: Output<Int>? = null,
    public val vMGroupName: Output<String>? = null,
    public val virtualNetworkProfile: Output<VirtualNetworkProfileArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.RoleArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.RoleArgs =
        com.pulumi.azurenative.hdinsight.inputs.RoleArgs.builder()
            .autoscaleConfiguration(
                autoscaleConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataDisksGroups(
                dataDisksGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .encryptDataDisks(encryptDataDisks?.applyValue({ args0 -> args0 }))
            .hardwareProfile(hardwareProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .minInstanceCount(minInstanceCount?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .osProfile(osProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .scriptActions(
                scriptActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .targetInstanceCount(targetInstanceCount?.applyValue({ args0 -> args0 }))
            .vMGroupName(vMGroupName?.applyValue({ args0 -> args0 }))
            .virtualNetworkProfile(
                virtualNetworkProfile?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [RoleArgs].
 */
@PulumiTagMarker
public class RoleArgsBuilder internal constructor() {
    private var autoscaleConfiguration: Output<AutoscaleArgs>? = null

    private var dataDisksGroups: Output<List<DataDisksGroupsArgs>>? = null

    private var encryptDataDisks: Output<Boolean>? = null

    private var hardwareProfile: Output<HardwareProfileArgs>? = null

    private var minInstanceCount: Output<Int>? = null

    private var name: Output<String>? = null

    private var osProfile: Output<OsProfileArgs>? = null

    private var scriptActions: Output<List<ScriptActionArgs>>? = null

    private var targetInstanceCount: Output<Int>? = null

    private var vMGroupName: Output<String>? = null

    private var virtualNetworkProfile: Output<VirtualNetworkProfileArgs>? = null

    /**
     * @param value The autoscale configurations.
     */
    @JvmName("tnvsqqlhjmpefmeg")
    public suspend fun autoscaleConfiguration(`value`: Output<AutoscaleArgs>) {
        this.autoscaleConfiguration = value
    }

    /**
     * @param value The data disks groups for the role.
     */
    @JvmName("adtsycwosoxhhnkl")
    public suspend fun dataDisksGroups(`value`: Output<List<DataDisksGroupsArgs>>) {
        this.dataDisksGroups = value
    }

    @JvmName("bixpdcgijjghnstq")
    public suspend fun dataDisksGroups(vararg values: Output<DataDisksGroupsArgs>) {
        this.dataDisksGroups = Output.all(values.asList())
    }

    /**
     * @param values The data disks groups for the role.
     */
    @JvmName("lfhaxwbytsvnancy")
    public suspend fun dataDisksGroups(values: List<Output<DataDisksGroupsArgs>>) {
        this.dataDisksGroups = Output.all(values)
    }

    /**
     * @param value Indicates whether encrypt the data disks.
     */
    @JvmName("vtjyxhebmuxkliit")
    public suspend fun encryptDataDisks(`value`: Output<Boolean>) {
        this.encryptDataDisks = value
    }

    /**
     * @param value The hardware profile.
     */
    @JvmName("sbwgbhixhnwurwnx")
    public suspend fun hardwareProfile(`value`: Output<HardwareProfileArgs>) {
        this.hardwareProfile = value
    }

    /**
     * @param value The minimum instance count of the cluster.
     */
    @JvmName("kmdrrorbiwdogujn")
    public suspend fun minInstanceCount(`value`: Output<Int>) {
        this.minInstanceCount = value
    }

    /**
     * @param value The name of the role.
     */
    @JvmName("akfekqqsnwfgytoe")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The operating system profile.
     */
    @JvmName("wiepuunkpielnjhm")
    public suspend fun osProfile(`value`: Output<OsProfileArgs>) {
        this.osProfile = value
    }

    /**
     * @param value The list of script actions on the role.
     */
    @JvmName("wiqfslipxyaiomnm")
    public suspend fun scriptActions(`value`: Output<List<ScriptActionArgs>>) {
        this.scriptActions = value
    }

    @JvmName("hiaxsjuicbhjtqnp")
    public suspend fun scriptActions(vararg values: Output<ScriptActionArgs>) {
        this.scriptActions = Output.all(values.asList())
    }

    /**
     * @param values The list of script actions on the role.
     */
    @JvmName("gsnurwyhvopljnrg")
    public suspend fun scriptActions(values: List<Output<ScriptActionArgs>>) {
        this.scriptActions = Output.all(values)
    }

    /**
     * @param value The instance count of the cluster.
     */
    @JvmName("vlurcslewtklimuu")
    public suspend fun targetInstanceCount(`value`: Output<Int>) {
        this.targetInstanceCount = value
    }

    /**
     * @param value The name of the virtual machine group.
     */
    @JvmName("vxnjiyljshaafmtc")
    public suspend fun vMGroupName(`value`: Output<String>) {
        this.vMGroupName = value
    }

    /**
     * @param value The virtual network profile.
     */
    @JvmName("ybdpmvhtmsoonnxn")
    public suspend fun virtualNetworkProfile(`value`: Output<VirtualNetworkProfileArgs>) {
        this.virtualNetworkProfile = value
    }

    /**
     * @param value The autoscale configurations.
     */
    @JvmName("rhbntpvtilghqkfy")
    public suspend fun autoscaleConfiguration(`value`: AutoscaleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoscaleConfiguration = mapped
    }

    /**
     * @param argument The autoscale configurations.
     */
    @JvmName("plbcoqlhisjtrynj")
    public suspend fun autoscaleConfiguration(argument: suspend AutoscaleArgsBuilder.() -> Unit) {
        val toBeMapped = AutoscaleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.autoscaleConfiguration = mapped
    }

    /**
     * @param value The data disks groups for the role.
     */
    @JvmName("uootfiyjotwpvuhl")
    public suspend fun dataDisksGroups(`value`: List<DataDisksGroupsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("xhpjbbnppfawgebg")
    public suspend
    fun dataDisksGroups(argument: List<suspend DataDisksGroupsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataDisksGroupsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("tlimgfoxmhkfaeut")
    public suspend fun dataDisksGroups(
        vararg
        argument: suspend DataDisksGroupsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataDisksGroupsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("hdqfhvbrsuruoxid")
    public suspend fun dataDisksGroups(argument: suspend DataDisksGroupsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataDisksGroupsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param values The data disks groups for the role.
     */
    @JvmName("fqydvtxehlhlfqvn")
    public suspend fun dataDisksGroups(vararg values: DataDisksGroupsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisksGroups = mapped
    }

    /**
     * @param value Indicates whether encrypt the data disks.
     */
    @JvmName("jkocpaxnvqxxoqrb")
    public suspend fun encryptDataDisks(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptDataDisks = mapped
    }

    /**
     * @param value The hardware profile.
     */
    @JvmName("rogaprkqcobkjpip")
    public suspend fun hardwareProfile(`value`: HardwareProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hardwareProfile = mapped
    }

    /**
     * @param argument The hardware profile.
     */
    @JvmName("hbhurvpmmlovixae")
    public suspend fun hardwareProfile(argument: suspend HardwareProfileArgsBuilder.() -> Unit) {
        val toBeMapped = HardwareProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hardwareProfile = mapped
    }

    /**
     * @param value The minimum instance count of the cluster.
     */
    @JvmName("sryuhdychraetmmc")
    public suspend fun minInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minInstanceCount = mapped
    }

    /**
     * @param value The name of the role.
     */
    @JvmName("tmbjtbtayjtlucvu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The operating system profile.
     */
    @JvmName("fdeufehstqhnlulb")
    public suspend fun osProfile(`value`: OsProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osProfile = mapped
    }

    /**
     * @param argument The operating system profile.
     */
    @JvmName("ugfratbofsfibyuy")
    public suspend fun osProfile(argument: suspend OsProfileArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osProfile = mapped
    }

    /**
     * @param value The list of script actions on the role.
     */
    @JvmName("pxuhdrvrytydmfcw")
    public suspend fun scriptActions(`value`: List<ScriptActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("klymmrdxwremgqpq")
    public suspend fun scriptActions(argument: List<suspend ScriptActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScriptActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("snooixvsytlbvlex")
    public suspend fun scriptActions(vararg argument: suspend ScriptActionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScriptActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("flhrkhvrprmscxlv")
    public suspend fun scriptActions(argument: suspend ScriptActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScriptActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param values The list of script actions on the role.
     */
    @JvmName("pyqjfuvdnucqaada")
    public suspend fun scriptActions(vararg values: ScriptActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptActions = mapped
    }

    /**
     * @param value The instance count of the cluster.
     */
    @JvmName("ooejnnsovbyknxqe")
    public suspend fun targetInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetInstanceCount = mapped
    }

    /**
     * @param value The name of the virtual machine group.
     */
    @JvmName("jgwldieevayypdec")
    public suspend fun vMGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vMGroupName = mapped
    }

    /**
     * @param value The virtual network profile.
     */
    @JvmName("roqgmsqfadouvuqx")
    public suspend fun virtualNetworkProfile(`value`: VirtualNetworkProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkProfile = mapped
    }

    /**
     * @param argument The virtual network profile.
     */
    @JvmName("getxnqclqhcadwrf")
    public suspend
    fun virtualNetworkProfile(argument: suspend VirtualNetworkProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworkProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.virtualNetworkProfile = mapped
    }

    internal fun build(): RoleArgs = RoleArgs(
        autoscaleConfiguration = autoscaleConfiguration,
        dataDisksGroups = dataDisksGroups,
        encryptDataDisks = encryptDataDisks,
        hardwareProfile = hardwareProfile,
        minInstanceCount = minInstanceCount,
        name = name,
        osProfile = osProfile,
        scriptActions = scriptActions,
        targetInstanceCount = targetInstanceCount,
        vMGroupName = vMGroupName,
        virtualNetworkProfile = virtualNetworkProfile,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/hdinsight/kotlin/inputs/RoleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hdinsight.kotlin.inputs

import com.pulumi.azurenative.hdinsight.inputs.RoleArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Describes a role on the cluster.
 * @property autoscaleConfiguration The autoscale configurations.
 * @property dataDisksGroups The data disks groups for the role.
 * @property encryptDataDisks Indicates whether encrypt the data disks.
 * @property hardwareProfile The hardware profile.
 * @property minInstanceCount The minimum instance count of the cluster.
 * @property name The name of the role.
 * @property osProfile The operating system profile.
 * @property scriptActions The list of script actions on the role.
 * @property targetInstanceCount The instance count of the cluster.
 * @property vMGroupName The name of the virtual machine group.
 * @property virtualNetworkProfile The virtual network profile.
 */
public data class RoleArgs(
    public val autoscaleConfiguration: Output<AutoscaleArgs>? = null,
    public val dataDisksGroups: Output<List<DataDisksGroupsArgs>>? = null,
    public val encryptDataDisks: Output<Boolean>? = null,
    public val hardwareProfile: Output<HardwareProfileArgs>? = null,
    public val minInstanceCount: Output<Int>? = null,
    public val name: Output<String>? = null,
    public val osProfile: Output<OsProfileArgs>? = null,
    public val scriptActions: Output<List<ScriptActionArgs>>? = null,
    public val targetInstanceCount: Output<Int>? = null,
    public val vMGroupName: Output<String>? = null,
    public val virtualNetworkProfile: Output<VirtualNetworkProfileArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.hdinsight.inputs.RoleArgs> {
    override fun toJava(): com.pulumi.azurenative.hdinsight.inputs.RoleArgs =
        com.pulumi.azurenative.hdinsight.inputs.RoleArgs.builder()
            .autoscaleConfiguration(
                autoscaleConfiguration?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .dataDisksGroups(
                dataDisksGroups?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .encryptDataDisks(encryptDataDisks?.applyValue({ args0 -> args0 }))
            .hardwareProfile(hardwareProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .minInstanceCount(minInstanceCount?.applyValue({ args0 -> args0 }))
            .name(name?.applyValue({ args0 -> args0 }))
            .osProfile(osProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .scriptActions(
                scriptActions?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .targetInstanceCount(targetInstanceCount?.applyValue({ args0 -> args0 }))
            .vMGroupName(vMGroupName?.applyValue({ args0 -> args0 }))
            .virtualNetworkProfile(
                virtualNetworkProfile?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [RoleArgs].
 */
@PulumiTagMarker
public class RoleArgsBuilder internal constructor() {
    private var autoscaleConfiguration: Output<AutoscaleArgs>? = null

    private var dataDisksGroups: Output<List<DataDisksGroupsArgs>>? = null

    private var encryptDataDisks: Output<Boolean>? = null

    private var hardwareProfile: Output<HardwareProfileArgs>? = null

    private var minInstanceCount: Output<Int>? = null

    private var name: Output<String>? = null

    private var osProfile: Output<OsProfileArgs>? = null

    private var scriptActions: Output<List<ScriptActionArgs>>? = null

    private var targetInstanceCount: Output<Int>? = null

    private var vMGroupName: Output<String>? = null

    private var virtualNetworkProfile: Output<VirtualNetworkProfileArgs>? = null

    /**
     * @param value The autoscale configurations.
     */
    @JvmName("mbigdrckiwbafcuj")
    public suspend fun autoscaleConfiguration(`value`: Output<AutoscaleArgs>) {
        this.autoscaleConfiguration = value
    }

    /**
     * @param value The data disks groups for the role.
     */
    @JvmName("qwjmxdxmkklxhhqb")
    public suspend fun dataDisksGroups(`value`: Output<List<DataDisksGroupsArgs>>) {
        this.dataDisksGroups = value
    }

    @JvmName("odqlsvjkrretqprj")
    public suspend fun dataDisksGroups(vararg values: Output<DataDisksGroupsArgs>) {
        this.dataDisksGroups = Output.all(values.asList())
    }

    /**
     * @param values The data disks groups for the role.
     */
    @JvmName("uxwqwoevgekmutar")
    public suspend fun dataDisksGroups(values: List<Output<DataDisksGroupsArgs>>) {
        this.dataDisksGroups = Output.all(values)
    }

    /**
     * @param value Indicates whether encrypt the data disks.
     */
    @JvmName("rsycpixmxvmqgiof")
    public suspend fun encryptDataDisks(`value`: Output<Boolean>) {
        this.encryptDataDisks = value
    }

    /**
     * @param value The hardware profile.
     */
    @JvmName("fhxjkufnnabfftyd")
    public suspend fun hardwareProfile(`value`: Output<HardwareProfileArgs>) {
        this.hardwareProfile = value
    }

    /**
     * @param value The minimum instance count of the cluster.
     */
    @JvmName("rpgcmpueyjtaipbq")
    public suspend fun minInstanceCount(`value`: Output<Int>) {
        this.minInstanceCount = value
    }

    /**
     * @param value The name of the role.
     */
    @JvmName("gepkdqyptutpkags")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value The operating system profile.
     */
    @JvmName("nxtfoclotlqdmayf")
    public suspend fun osProfile(`value`: Output<OsProfileArgs>) {
        this.osProfile = value
    }

    /**
     * @param value The list of script actions on the role.
     */
    @JvmName("tcsljstipypsxnjh")
    public suspend fun scriptActions(`value`: Output<List<ScriptActionArgs>>) {
        this.scriptActions = value
    }

    @JvmName("hwgcjoelxmhxetta")
    public suspend fun scriptActions(vararg values: Output<ScriptActionArgs>) {
        this.scriptActions = Output.all(values.asList())
    }

    /**
     * @param values The list of script actions on the role.
     */
    @JvmName("uhekugtvlavjrvbo")
    public suspend fun scriptActions(values: List<Output<ScriptActionArgs>>) {
        this.scriptActions = Output.all(values)
    }

    /**
     * @param value The instance count of the cluster.
     */
    @JvmName("qjiiqvnwpqucmnbq")
    public suspend fun targetInstanceCount(`value`: Output<Int>) {
        this.targetInstanceCount = value
    }

    /**
     * @param value The name of the virtual machine group.
     */
    @JvmName("aycwruvucwjprfsf")
    public suspend fun vMGroupName(`value`: Output<String>) {
        this.vMGroupName = value
    }

    /**
     * @param value The virtual network profile.
     */
    @JvmName("dwonfsdwsxqjgrek")
    public suspend fun virtualNetworkProfile(`value`: Output<VirtualNetworkProfileArgs>) {
        this.virtualNetworkProfile = value
    }

    /**
     * @param value The autoscale configurations.
     */
    @JvmName("sfxvbilosrqjkbse")
    public suspend fun autoscaleConfiguration(`value`: AutoscaleArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.autoscaleConfiguration = mapped
    }

    /**
     * @param argument The autoscale configurations.
     */
    @JvmName("swqrsveeqwhuicxd")
    public suspend fun autoscaleConfiguration(argument: suspend AutoscaleArgsBuilder.() -> Unit) {
        val toBeMapped = AutoscaleArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.autoscaleConfiguration = mapped
    }

    /**
     * @param value The data disks groups for the role.
     */
    @JvmName("pnjykfvriagkkfbq")
    public suspend fun dataDisksGroups(`value`: List<DataDisksGroupsArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("vdiymdssqxkpqguo")
    public suspend
    fun dataDisksGroups(argument: List<suspend DataDisksGroupsArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            DataDisksGroupsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("snoihxjyeqavnwmb")
    public suspend fun dataDisksGroups(
        vararg
        argument: suspend DataDisksGroupsArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            DataDisksGroupsArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param argument The data disks groups for the role.
     */
    @JvmName("hlqtjrtogrtluygi")
    public suspend fun dataDisksGroups(argument: suspend DataDisksGroupsArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(DataDisksGroupsArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.dataDisksGroups = mapped
    }

    /**
     * @param values The data disks groups for the role.
     */
    @JvmName("bnyvknmjqqmawimo")
    public suspend fun dataDisksGroups(vararg values: DataDisksGroupsArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dataDisksGroups = mapped
    }

    /**
     * @param value Indicates whether encrypt the data disks.
     */
    @JvmName("ehahkawaryqlfivh")
    public suspend fun encryptDataDisks(`value`: Boolean?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.encryptDataDisks = mapped
    }

    /**
     * @param value The hardware profile.
     */
    @JvmName("hlsfvyddvuolpnin")
    public suspend fun hardwareProfile(`value`: HardwareProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.hardwareProfile = mapped
    }

    /**
     * @param argument The hardware profile.
     */
    @JvmName("xrtnmukhatbjlcat")
    public suspend fun hardwareProfile(argument: suspend HardwareProfileArgsBuilder.() -> Unit) {
        val toBeMapped = HardwareProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hardwareProfile = mapped
    }

    /**
     * @param value The minimum instance count of the cluster.
     */
    @JvmName("txapmfyldhtolnok")
    public suspend fun minInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.minInstanceCount = mapped
    }

    /**
     * @param value The name of the role.
     */
    @JvmName("kerelnkobufewdbv")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value The operating system profile.
     */
    @JvmName("lccymhcwaulctsst")
    public suspend fun osProfile(`value`: OsProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.osProfile = mapped
    }

    /**
     * @param argument The operating system profile.
     */
    @JvmName("pboiiopjofaobgbf")
    public suspend fun osProfile(argument: suspend OsProfileArgsBuilder.() -> Unit) {
        val toBeMapped = OsProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.osProfile = mapped
    }

    /**
     * @param value The list of script actions on the role.
     */
    @JvmName("bevscacssmiewyjb")
    public suspend fun scriptActions(`value`: List<ScriptActionArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("ycxyvebnxyaeimlh")
    public suspend fun scriptActions(argument: List<suspend ScriptActionArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            ScriptActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("oljkcbejcfhngutu")
    public suspend fun scriptActions(vararg argument: suspend ScriptActionArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            ScriptActionArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param argument The list of script actions on the role.
     */
    @JvmName("tpamiuvogggikail")
    public suspend fun scriptActions(argument: suspend ScriptActionArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(ScriptActionArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.scriptActions = mapped
    }

    /**
     * @param values The list of script actions on the role.
     */
    @JvmName("bavqlfhvnixiwybw")
    public suspend fun scriptActions(vararg values: ScriptActionArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.scriptActions = mapped
    }

    /**
     * @param value The instance count of the cluster.
     */
    @JvmName("qvaefjooryicuxcb")
    public suspend fun targetInstanceCount(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.targetInstanceCount = mapped
    }

    /**
     * @param value The name of the virtual machine group.
     */
    @JvmName("acexsdjakcubpvic")
    public suspend fun vMGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vMGroupName = mapped
    }

    /**
     * @param value The virtual network profile.
     */
    @JvmName("ogmgiufitqkvnepx")
    public suspend fun virtualNetworkProfile(`value`: VirtualNetworkProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.virtualNetworkProfile = mapped
    }

    /**
     * @param argument The virtual network profile.
     */
    @JvmName("gogysijttyvrftmf")
    public suspend
    fun virtualNetworkProfile(argument: suspend VirtualNetworkProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworkProfileArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.virtualNetworkProfile = mapped
    }

    internal fun build(): RoleArgs = RoleArgs(
        autoscaleConfiguration = autoscaleConfiguration,
        dataDisksGroups = dataDisksGroups,
        encryptDataDisks = encryptDataDisks,
        hardwareProfile = hardwareProfile,
        minInstanceCount = minInstanceCount,
        name = name,
        osProfile = osProfile,
        scriptActions = scriptActions,
        targetInstanceCount = targetInstanceCount,
        vMGroupName = vMGroupName,
        virtualNetworkProfile = virtualNetworkProfile,
    )
}
